<?php
/**
 * Main theme functions
 *
 * @package WordPress
 * @subpackage Apricot
 * @since Apricot 1.0
 */


/* Initial Theme Actions */
function apricot_initialize()
{
	add_action( 'wp_enqueue_scripts', 'apricot_scripts_and_styles', 999 );
	add_action( 'widgets_init', 'apricot_register_sidebars' );
	load_theme_textdomain( 'apricot', get_template_directory() . '/translation' );
	apricot_theme_support();
}
add_action( 'after_setup_theme', 'apricot_initialize' );



/* Buffer Template Content */
function load_template_part($template_name, $part_name=null)
{
	ob_start();
	get_template_part($template_name, $part_name);
	$var = ob_get_contents();
	ob_end_clean();
	return $var;
}


function apricot_strip_first_content_gallery( $content ) {
	if ( 'gallery' == get_post_format() ) {
		$regex = '/\[gallery.*]/';
		$content = preg_replace( $regex, '', $content, 1 );
	}
	return $content;
}


/* Allow Posts to be Marked as Featured */
function apricot_add_meta_box() {

	$screens = array( 'post', 'page' );

	foreach ( $screens as $screen ) {

		add_meta_box(
			'apricot_sectionid',
			__( 'Apricot Theme Options', 'apricot_textdomain' ),
			'apricot_meta_box_callback',
			$screen,
			'side',
			'core'
			);
	}
}
function apricot_meta_box_callback( $post ) {

	wp_nonce_field( 'apricot_meta_box', 'apricot_meta_box_nonce' );

	$value = get_post_meta( $post->ID, 'apricot_is_checked', true );
	$value = $value=='true' ? 'checked' : '';
	echo '<label for="apricot_new_field">';
	echo '<input '.$value.' value="true" type="checkbox" id="apricot_new_field" name="apricot_new_field" />';
	_e( 'Set this as featured post', 'apricot_textdomain' );
	echo '</label> ';
	
}
function apricot_save_meta_box_data( $post_id ) {


	if ( ! isset( $_POST['apricot_meta_box_nonce'] ) ) {
		return;
	}

	if ( ! wp_verify_nonce( $_POST['apricot_meta_box_nonce'], 'apricot_meta_box' ) ) {
		return;
	}

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	if ( ! isset( $_POST['apricot_new_field'] ) ) {
		$_POST['apricot_new_field'] = false;
	}
	$my_data = sanitize_text_field( $_POST['apricot_new_field'] );
	update_post_meta( $post_id, 'apricot_is_checked', $my_data );
}
add_action( 'save_post', 'apricot_save_meta_box_data' );
add_action( 'add_meta_boxes', 'apricot_add_meta_box' );



/* Setting Theme Options, for the Live Preview */
$theme_columns = get_theme_mod('apricot_col_layout','one');
$theme_columns = isset($_COOKIE['layout']) ? $_COOKIE['layout'] : $theme_columns;

$box_layout = get_theme_mod('apricot_box_layout','top');
$box_layout = isset($_COOKIE['box']) ? $_COOKIE['box'] : $box_layout;

$theme_color = get_theme_mod('apricot_theme_color','#f08080');
$theme_color = isset($_COOKIE['color']) ? $_COOKIE['color'] : $theme_color;

$sidebar_home = get_theme_mod('apricot_sidebar_home','1');
$sidebar_home = isset($_COOKIE['sidebar']) ? $_COOKIE['sidebar'] : $sidebar_home;

$sidebar_post = get_theme_mod('apricot_sidebar_post','1');
$sidebar_post = isset($_COOKIE['sidebar']) ? $_COOKIE['sidebar'] : $sidebar_post;

$sidebar_archive = get_theme_mod('apricot_sidebar_archive','1');
$sidebar_archive = isset($_COOKIE['sidebar']) ? $_COOKIE['sidebar'] : $sidebar_archive;

global $featured, $box_layout, $theme_columns, $theme_color, $sidebar_home, $sidebar_post, $sidebar_archive;


/* Set Content Width */
if ( ! isset( $content_width ) )
	$content_width = 700;





/* Custom Social Links for User Profiles */
add_filter('user_contactmethods', 'apricot_user_contactmethods');
function apricot_user_contactmethods($user_contactmethods){
	$user_contactmethods['display'] = 'Display Pic Link';
	$user_contactmethods['tag-line'] = 'Tag Line';
	$user_contactmethods['facebook'] = 'Facebook Link';
	$user_contactmethods['twitter'] = 'Twitter Link';
	$user_contactmethods['linkedin'] = 'LinkedIn Link';
	$user_contactmethods['instagram'] = 'Instagram Link';
	$user_contactmethods['pinterest'] = 'Pinterest Link';
	$user_contactmethods['gplus'] = 'Google+ Link';
	$user_contactmethods['tumblr'] = 'Tumblr Link';
	return $user_contactmethods;
}


/* Custom User Pic Display */
add_filter( 'get_avatar' , 'apricot_custom_avatar' , 1 , 4 );
function apricot_custom_avatar( $avatar, $id_or_email, $size, $default ) {
	$user = false;

	if ( is_numeric( $id_or_email ) ) {

		$id = (int) $id_or_email;
		$user = get_user_by( 'id' , $id );

	} elseif ( is_object( $id_or_email ) ) {

		if ( ! empty( $id_or_email->user_id ) ) {
			$id = (int) $id_or_email->user_id;
			$user = get_user_by( 'id' , $id );
		}

	} else {
		$user = get_user_by( 'email', $id_or_email ); 
	}

	if ( $user && is_object( $user ) ) {

		if (get_the_author_meta('display',$user->data->ID))
		{
			$image = "<img alt='' src='".get_the_author_meta('display',$user->data->ID)."' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
		}
		else
		{
			$image = $avatar;
		}
		return $image;
	}
	return '';
}

remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);



/* Register Sidebar */
function apricot_register_sidebars() {
	register_widget( 'apricot_recent_posts' );
	register_widget( 'apricot_recent_comments' );
	register_widget( 'apricot_site_author' );
	register_sidebar(array(
		'id' => 'sidebar-1',
		'name' => __( 'Sidebar', 'apricottheme' ),
		'description' => __( '', 'apricottheme' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
	register_sidebar(array(
		'id' => 'sidebar-2',
		'name' => __( 'Footer', 'apricottheme' ),
		'description' => __( '', 'apricottheme' ),
		'before_widget' => '<div id="%1$s" data-equalizer-watch class="widget large-3 medium-6 small-12 column %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
		));
}



/* Add to Body Class */
add_filter('body_class', 'apricot_body_classes');
function apricot_body_classes($classes) {
	global $theme_columns,$box_layout;
	$classes[] = 'header-layout-'.$box_layout;
	$classes[] = 'column-layout-'.$theme_columns;
	return $classes;
}

add_filter('post_class', 'apricot_post_classes');
function apricot_post_classes($classes) {
	$classes[] = 'card';
	return $classes;
}



/* Theme Customizer */
add_action( 'customize_register', 'apricot_theme_customizer' );
function apricot_theme_customizer($wp_customize) {

	$google_fonts = array(''=>'Default','ABeeZee'=>'ABeeZee','Abel'=>'Abel','Abril Fatface'=>'Abril Fatface','Aclonica'=>'Aclonica','Acme'=>'Acme','Actor'=>'Actor','Adamina'=>'Adamina','Advent Pro'=>'Advent Pro','Aguafina Script'=>'Aguafina Script','Akronim'=>'Akronim','Aladin'=>'Aladin','Aldrich'=>'Aldrich','Alef'=>'Alef','Alegreya'=>'Alegreya','Alegreya Sans'=>'Alegreya Sans','Alegreya Sans SC'=>'Alegreya Sans SC','Alegreya SC'=>'Alegreya SC','Alex Brush'=>'Alex Brush','Alfa Slab One'=>'Alfa Slab One','Alice'=>'Alice','Alike'=>'Alike','Alike Angular'=>'Alike Angular','Allan'=>'Allan','Allerta'=>'Allerta','Allerta Stencil'=>'Allerta Stencil','Allura'=>'Allura','Almendra'=>'Almendra','Almendra Display'=>'Almendra Display','Almendra SC'=>'Almendra SC','Amarante'=>'Amarante','Amaranth'=>'Amaranth','Amatic SC'=>'Amatic SC','Amethysta'=>'Amethysta','Anaheim'=>'Anaheim','Andada'=>'Andada','Andika'=>'Andika','Angkor'=>'Angkor','Annie Use Your Telescope'=>'Annie Use Your Telescope','Anonymous Pro'=>'Anonymous Pro','Antic'=>'Antic','Antic Didone'=>'Antic Didone','Antic Slab'=>'Antic Slab','Anton'=>'Anton','Arapey'=>'Arapey','Arbutus'=>'Arbutus','Arbutus Slab'=>'Arbutus Slab','Architects Daughter'=>'Architects Daughter','Archivo Black'=>'Archivo Black','Archivo Narrow'=>'Archivo Narrow','Arimo'=>'Arimo','Arizonia'=>'Arizonia','Armata'=>'Armata','Artifika'=>'Artifika','Arvo'=>'Arvo','Asap'=>'Asap','Asset'=>'Asset','Astloch'=>'Astloch','Asul'=>'Asul','Atomic Age'=>'Atomic Age','Aubrey'=>'Aubrey','Audiowide'=>'Audiowide','Autour One'=>'Autour One','Average'=>'Average','Average Sans'=>'Average Sans','Averia Gruesa Libre'=>'Averia Gruesa Libre','Averia Libre'=>'Averia Libre','Averia Sans Libre'=>'Averia Sans Libre','Averia Serif Libre'=>'Averia Serif Libre','Bad Script'=>'Bad Script','Balthazar'=>'Balthazar','Bangers'=>'Bangers','Basic'=>'Basic','Battambang'=>'Battambang','Baumans'=>'Baumans','Bayon'=>'Bayon','Belgrano'=>'Belgrano','Belleza'=>'Belleza','BenchNine'=>'BenchNine','Bentham'=>'Bentham','Berkshire Swash'=>'Berkshire Swash','Bevan'=>'Bevan','Bigelow Rules'=>'Bigelow Rules','Bigshot One'=>'Bigshot One','Bilbo'=>'Bilbo','Bilbo Swash Caps'=>'Bilbo Swash Caps','Bitter'=>'Bitter','Black Ops One'=>'Black Ops One','Bokor'=>'Bokor','Bonbon'=>'Bonbon','Boogaloo'=>'Boogaloo','Bowlby One'=>'Bowlby One','Bowlby One SC'=>'Bowlby One SC','Brawler'=>'Brawler','Bree Serif'=>'Bree Serif','Bubblegum Sans'=>'Bubblegum Sans','Bubbler One'=>'Bubbler One','Buda'=>'Buda','Buenard'=>'Buenard','Butcherman'=>'Butcherman','Butterfly Kids'=>'Butterfly Kids','Cabin'=>'Cabin','Cabin Condensed'=>'Cabin Condensed','Cabin Sketch'=>'Cabin Sketch','Caesar Dressing'=>'Caesar Dressing','Cagliostro'=>'Cagliostro','Calligraffitti'=>'Calligraffitti','Cambo'=>'Cambo','Candal'=>'Candal','Cantarell'=>'Cantarell','Cantata One'=>'Cantata One','Cantora One'=>'Cantora One','Capriola'=>'Capriola','Cardo'=>'Cardo','Carme'=>'Carme','Carrois Gothic'=>'Carrois Gothic','Carrois Gothic SC'=>'Carrois Gothic SC','Carter One'=>'Carter One','Caudex'=>'Caudex','Cedarville Cursive'=>'Cedarville Cursive','Ceviche One'=>'Ceviche One','Changa One'=>'Changa One','Chango'=>'Chango','Chau Philomene One'=>'Chau Philomene One','Chela One'=>'Chela One','Chelsea Market'=>'Chelsea Market','Chenla'=>'Chenla','Cherry Cream Soda'=>'Cherry Cream Soda','Cherry Swash'=>'Cherry Swash','Chewy'=>'Chewy','Chicle'=>'Chicle','Chivo'=>'Chivo','Cinzel'=>'Cinzel','Cinzel Decorative'=>'Cinzel Decorative','Clicker Script'=>'Clicker Script','Coda'=>'Coda','Coda Caption'=>'Coda Caption','Codystar'=>'Codystar','Combo'=>'Combo','Comfortaa'=>'Comfortaa','Coming Soon'=>'Coming Soon','Concert One'=>'Concert One','Condiment'=>'Condiment','Content'=>'Content','Contrail One'=>'Contrail One','Convergence'=>'Convergence','Cookie'=>'Cookie','Copse'=>'Copse','Corben'=>'Corben','Courgette'=>'Courgette','Cousine'=>'Cousine','Coustard'=>'Coustard','Covered By Your Grace'=>'Covered By Your Grace','Crafty Girls'=>'Crafty Girls','Creepster'=>'Creepster','Crete Round'=>'Crete Round','Crimson Text'=>'Crimson Text','Croissant One'=>'Croissant One','Crushed'=>'Crushed','Cuprum'=>'Cuprum','Cutive'=>'Cutive','Cutive Mono'=>'Cutive Mono','Damion'=>'Damion','Dancing Script'=>'Dancing Script','Dangrek'=>'Dangrek','Dawning of a New Day'=>'Dawning of a New Day','Days One'=>'Days One','Delius'=>'Delius','Delius Swash Caps'=>'Delius Swash Caps','Delius Unicase'=>'Delius Unicase','Della Respira'=>'Della Respira','Denk One'=>'Denk One','Devonshire'=>'Devonshire','Dhurjati'=>'Dhurjati','Didact Gothic'=>'Didact Gothic','Diplomata'=>'Diplomata','Diplomata SC'=>'Diplomata SC','Domine'=>'Domine','Donegal One'=>'Donegal One','Doppio One'=>'Doppio One','Dorsa'=>'Dorsa','Dosis'=>'Dosis','Dr Sugiyama'=>'Dr Sugiyama','Droid Sans'=>'Droid Sans','Droid Sans Mono'=>'Droid Sans Mono','Droid Serif'=>'Droid Serif','Duru Sans'=>'Duru Sans','Dynalight'=>'Dynalight','Eagle Lake'=>'Eagle Lake','Eater'=>'Eater','EB Garamond'=>'EB Garamond','Economica'=>'Economica','Ek Mukta'=>'Ek Mukta','Electrolize'=>'Electrolize','Elsie'=>'Elsie','Elsie Swash Caps'=>'Elsie Swash Caps','Emblema One'=>'Emblema One','Emilys Candy'=>'Emilys Candy','Engagement'=>'Engagement','Englebert'=>'Englebert','Enriqueta'=>'Enriqueta','Erica One'=>'Erica One','Esteban'=>'Esteban','Euphoria Script'=>'Euphoria Script','Ewert'=>'Ewert','Exo'=>'Exo','Exo 2'=>'Exo 2','Expletus Sans'=>'Expletus Sans','Fanwood Text'=>'Fanwood Text','Fascinate'=>'Fascinate','Fascinate Inline'=>'Fascinate Inline','Faster One'=>'Faster One','Fasthand'=>'Fasthand','Fauna One'=>'Fauna One','Federant'=>'Federant','Federo'=>'Federo','Felipa'=>'Felipa','Fenix'=>'Fenix','Finger Paint'=>'Finger Paint','Fira Mono'=>'Fira Mono','Fira Sans'=>'Fira Sans','Fjalla One'=>'Fjalla One','Fjord One'=>'Fjord One','Flamenco'=>'Flamenco','Flavors'=>'Flavors','Fondamento'=>'Fondamento','Fontdiner Swanky'=>'Fontdiner Swanky','Forum'=>'Forum','Francois One'=>'Francois One','Freckle Face'=>'Freckle Face','Fredericka the Great'=>'Fredericka the Great','Fredoka One'=>'Fredoka One','Freehand'=>'Freehand','Fresca'=>'Fresca','Frijole'=>'Frijole','Fruktur'=>'Fruktur','Fugaz One'=>'Fugaz One','Gabriela'=>'Gabriela','Gafata'=>'Gafata','Galdeano'=>'Galdeano','Galindo'=>'Galindo','Gentium Basic'=>'Gentium Basic','Gentium Book Basic'=>'Gentium Book Basic','Geo'=>'Geo','Geostar'=>'Geostar','Geostar Fill'=>'Geostar Fill','Germania One'=>'Germania One','GFS Didot'=>'GFS Didot','GFS Neohellenic'=>'GFS Neohellenic','Gidugu'=>'Gidugu','Gilda Display'=>'Gilda Display','Give You Glory'=>'Give You Glory','Glass Antiqua'=>'Glass Antiqua','Glegoo'=>'Glegoo','Gloria Hallelujah'=>'Gloria Hallelujah','Goblin One'=>'Goblin One','Gochi Hand'=>'Gochi Hand','Gorditas'=>'Gorditas','Goudy Bookletter 1911'=>'Goudy Bookletter 1911','Graduate'=>'Graduate','Grand Hotel'=>'Grand Hotel','Gravitas One'=>'Gravitas One','Great Vibes'=>'Great Vibes','Griffy'=>'Griffy','Gruppo'=>'Gruppo','Gudea'=>'Gudea','Gurajada'=>'Gurajada','Habibi'=>'Habibi','Halant'=>'Halant','Hammersmith One'=>'Hammersmith One','Hanalei'=>'Hanalei','Hanalei Fill'=>'Hanalei Fill','Handlee'=>'Handlee','Hanuman'=>'Hanuman','Happy Monkey'=>'Happy Monkey','Headland One'=>'Headland One','Henny Penny'=>'Henny Penny','Herr Von Muellerhoff'=>'Herr Von Muellerhoff','Hind'=>'Hind','Holtwood One SC'=>'Holtwood One SC','Homemade Apple'=>'Homemade Apple','Homenaje'=>'Homenaje','Iceberg'=>'Iceberg','Iceland'=>'Iceland','IM Fell Double Pica'=>'IM Fell Double Pica','IM Fell Double Pica SC'=>'IM Fell Double Pica SC','IM Fell DW Pica'=>'IM Fell DW Pica','IM Fell DW Pica SC'=>'IM Fell DW Pica SC','IM Fell English'=>'IM Fell English','IM Fell English SC'=>'IM Fell English SC','IM Fell French Canon'=>'IM Fell French Canon','IM Fell French Canon SC'=>'IM Fell French Canon SC','IM Fell Great Primer'=>'IM Fell Great Primer','IM Fell Great Primer SC'=>'IM Fell Great Primer SC','Imprima'=>'Imprima','Inconsolata'=>'Inconsolata','Inder'=>'Inder','Indie Flower'=>'Indie Flower','Inika'=>'Inika','Irish Grover'=>'Irish Grover','Istok Web'=>'Istok Web','Italiana'=>'Italiana','Italianno'=>'Italianno','Jacques Francois'=>'Jacques Francois','Jacques Francois Shadow'=>'Jacques Francois Shadow','Jim Nightshade'=>'Jim Nightshade','Jockey One'=>'Jockey One','Jolly Lodger'=>'Jolly Lodger','Josefin Sans'=>'Josefin Sans','Josefin Slab'=>'Josefin Slab','Joti One'=>'Joti One','Judson'=>'Judson','Julee'=>'Julee','Julius Sans One'=>'Julius Sans One','Junge'=>'Junge','Jura'=>'Jura','Just Another Hand'=>'Just Another Hand','Just Me Again Down Here'=>'Just Me Again Down Here','Kalam'=>'Kalam','Kameron'=>'Kameron','Kantumruy'=>'Kantumruy','Karla'=>'Karla','Karma'=>'Karma','Kaushan Script'=>'Kaushan Script','Kavoon'=>'Kavoon','Kdam Thmor'=>'Kdam Thmor','Keania One'=>'Keania One','Kelly Slab'=>'Kelly Slab','Kenia'=>'Kenia','Khand'=>'Khand','Khmer'=>'Khmer','Kite One'=>'Kite One','Knewave'=>'Knewave','Kotta One'=>'Kotta One','Koulen'=>'Koulen','Kranky'=>'Kranky','Kreon'=>'Kreon','Kristi'=>'Kristi','Krona One'=>'Krona One','La Belle Aurore'=>'La Belle Aurore','Laila'=>'Laila','Lakki Reddy'=>'Lakki Reddy','Lancelot'=>'Lancelot','Lato'=>'Lato','League Script'=>'League Script','Leckerli One'=>'Leckerli One','Ledger'=>'Ledger','Lekton'=>'Lekton','Lemon'=>'Lemon','Libre Baskerville'=>'Libre Baskerville','Life Savers'=>'Life Savers','Lilita One'=>'Lilita One','Lily Script One'=>'Lily Script One','Limelight'=>'Limelight','Linden Hill'=>'Linden Hill','Lobster'=>'Lobster','Lobster Two'=>'Lobster Two','Londrina Outline'=>'Londrina Outline','Londrina Shadow'=>'Londrina Shadow','Londrina Sketch'=>'Londrina Sketch','Londrina Solid'=>'Londrina Solid','Lora'=>'Lora','Love Ya Like A Sister'=>'Love Ya Like A Sister','Loved by the King'=>'Loved by the King','Lovers Quarrel'=>'Lovers Quarrel','Luckiest Guy'=>'Luckiest Guy','Lusitana'=>'Lusitana','Lustria'=>'Lustria','Macondo'=>'Macondo','Macondo Swash Caps'=>'Macondo Swash Caps','Magra'=>'Magra','Maiden Orange'=>'Maiden Orange','Mako'=>'Mako','Mallanna'=>'Mallanna','Mandali'=>'Mandali','Marcellus'=>'Marcellus','Marcellus SC'=>'Marcellus SC','Marck Script'=>'Marck Script','Margarine'=>'Margarine','Marko One'=>'Marko One','Marmelad'=>'Marmelad','Marvel'=>'Marvel','Mate'=>'Mate','Mate SC'=>'Mate SC','Maven Pro'=>'Maven Pro','McLaren'=>'McLaren','Meddon'=>'Meddon','MedievalSharp'=>'MedievalSharp','Medula One'=>'Medula One','Megrim'=>'Megrim','Meie Script'=>'Meie Script','Merienda'=>'Merienda','Merienda One'=>'Merienda One','Merriweather'=>'Merriweather','Merriweather Sans'=>'Merriweather Sans','Metal'=>'Metal','Metal Mania'=>'Metal Mania','Metamorphous'=>'Metamorphous','Metrophobic'=>'Metrophobic','Michroma'=>'Michroma','Milonga'=>'Milonga','Miltonian'=>'Miltonian','Miltonian Tattoo'=>'Miltonian Tattoo','Miniver'=>'Miniver','Miss Fajardose'=>'Miss Fajardose','Modern Antiqua'=>'Modern Antiqua','Molengo'=>'Molengo','Molle'=>'Molle','Monda'=>'Monda','Monofett'=>'Monofett','Monoton'=>'Monoton','Monsieur La Doulaise'=>'Monsieur La Doulaise','Montaga'=>'Montaga','Montez'=>'Montez','Montserrat'=>'Montserrat','Montserrat Alternates'=>'Montserrat Alternates','Montserrat Subrayada'=>'Montserrat Subrayada','Moul'=>'Moul','Moulpali'=>'Moulpali','Mountains of Christmas'=>'Mountains of Christmas','Mouse Memoirs'=>'Mouse Memoirs','Mr Bedfort'=>'Mr Bedfort','Mr Dafoe'=>'Mr Dafoe','Mr De Haviland'=>'Mr De Haviland','Mrs Saint Delafield'=>'Mrs Saint Delafield','Mrs Sheppards'=>'Mrs Sheppards','Muli'=>'Muli','Mystery Quest'=>'Mystery Quest','Neucha'=>'Neucha','Neuton'=>'Neuton','New Rocker'=>'New Rocker','News Cycle'=>'News Cycle','Niconne'=>'Niconne','Nixie One'=>'Nixie One','Nobile'=>'Nobile','Nokora'=>'Nokora','Norican'=>'Norican','Nosifer'=>'Nosifer','Nothing You Could Do'=>'Nothing You Could Do','Noticia Text'=>'Noticia Text','Noto Sans'=>'Noto Sans','Noto Serif'=>'Noto Serif','Nova Cut'=>'Nova Cut','Nova Flat'=>'Nova Flat','Nova Mono'=>'Nova Mono','Nova Oval'=>'Nova Oval','Nova Round'=>'Nova Round','Nova Script'=>'Nova Script','Nova Slim'=>'Nova Slim','Nova Square'=>'Nova Square','NTR'=>'NTR','Numans'=>'Numans','Nunito'=>'Nunito','Odor Mean Chey'=>'Odor Mean Chey','Offside'=>'Offside','Old Standard TT'=>'Old Standard TT','Oldenburg'=>'Oldenburg','Oleo Script'=>'Oleo Script','Oleo Script Swash Caps'=>'Oleo Script Swash Caps','Open Sans'=>'Open Sans','Open Sans Condensed'=>'Open Sans Condensed','Oranienbaum'=>'Oranienbaum','Orbitron'=>'Orbitron','Oregano'=>'Oregano','Orienta'=>'Orienta','Original Surfer'=>'Original Surfer','Oswald'=>'Oswald','Over the Rainbow'=>'Over the Rainbow','Overlock'=>'Overlock','Overlock SC'=>'Overlock SC','Ovo'=>'Ovo','Oxygen'=>'Oxygen','Oxygen Mono'=>'Oxygen Mono','Pacifico'=>'Pacifico','Paprika'=>'Paprika','Parisienne'=>'Parisienne','Passero One'=>'Passero One','Passion One'=>'Passion One','Pathway Gothic One'=>'Pathway Gothic One','Patrick Hand'=>'Patrick Hand','Patrick Hand SC'=>'Patrick Hand SC','Patua One'=>'Patua One','Paytone One'=>'Paytone One','Peddana'=>'Peddana','Peralta'=>'Peralta','Permanent Marker'=>'Permanent Marker','Petit Formal Script'=>'Petit Formal Script','Petrona'=>'Petrona','Philosopher'=>'Philosopher','Piedra'=>'Piedra','Pinyon Script'=>'Pinyon Script','Pirata One'=>'Pirata One','Plaster'=>'Plaster','Play'=>'Play','Playball'=>'Playball','Playfair Display'=>'Playfair Display','Playfair Display SC'=>'Playfair Display SC','Podkova'=>'Podkova','Poiret One'=>'Poiret One','Poller One'=>'Poller One','Poly'=>'Poly','Pompiere'=>'Pompiere','Pontano Sans'=>'Pontano Sans','Port Lligat Sans'=>'Port Lligat Sans','Port Lligat Slab'=>'Port Lligat Slab','Prata'=>'Prata','Preahvihear'=>'Preahvihear','Press Start 2P'=>'Press Start 2P','Princess Sofia'=>'Princess Sofia','Prociono'=>'Prociono','Prosto One'=>'Prosto One','PT Mono'=>'PT Mono','PT Sans'=>'PT Sans','PT Sans Caption'=>'PT Sans Caption','PT Sans Narrow'=>'PT Sans Narrow','PT Serif'=>'PT Serif','PT Serif Caption'=>'PT Serif Caption','Puritan'=>'Puritan','Purple Purse'=>'Purple Purse','Quando'=>'Quando','Quantico'=>'Quantico','Quattrocento'=>'Quattrocento','Quattrocento Sans'=>'Quattrocento Sans','Questrial'=>'Questrial','Quicksand'=>'Quicksand','Quintessential'=>'Quintessential','Qwigley'=>'Qwigley','Racing Sans One'=>'Racing Sans One','Radley'=>'Radley','Rajdhani'=>'Rajdhani','Raleway'=>'Raleway','Raleway Dots'=>'Raleway Dots','Ramabhadra'=>'Ramabhadra','Ramaraja'=>'Ramaraja','Rambla'=>'Rambla','Rammetto One'=>'Rammetto One','Ranchers'=>'Ranchers','Rancho'=>'Rancho','Rationale'=>'Rationale','Ravi Prakash'=>'Ravi Prakash','Redressed'=>'Redressed','Reenie Beanie'=>'Reenie Beanie','Revalia'=>'Revalia','Ribeye'=>'Ribeye','Ribeye Marrow'=>'Ribeye Marrow','Righteous'=>'Righteous','Risque'=>'Risque','Roboto'=>'Roboto','Roboto Condensed'=>'Roboto Condensed','Roboto Slab'=>'Roboto Slab','Rochester'=>'Rochester','Rock Salt'=>'Rock Salt','Rokkitt'=>'Rokkitt','Romanesco'=>'Romanesco','Ropa Sans'=>'Ropa Sans','Rosario'=>'Rosario','Rosarivo'=>'Rosarivo','Rouge Script'=>'Rouge Script','Rozha One'=>'Rozha One','Rubik Mono One'=>'Rubik Mono One','Rubik One'=>'Rubik One','Ruda'=>'Ruda','Rufina'=>'Rufina','Ruge Boogie'=>'Ruge Boogie','Ruluko'=>'Ruluko','Rum Raisin'=>'Rum Raisin','Ruslan Display'=>'Ruslan Display','Russo One'=>'Russo One','Ruthie'=>'Ruthie','Rye'=>'Rye','Sacramento'=>'Sacramento','Sail'=>'Sail','Salsa'=>'Salsa','Sanchez'=>'Sanchez','Sancreek'=>'Sancreek','Sansita One'=>'Sansita One','Sarina'=>'Sarina','Sarpanch'=>'Sarpanch','Satisfy'=>'Satisfy','Scada'=>'Scada','Schoolbell'=>'Schoolbell','Seaweed Script'=>'Seaweed Script','Sevillana'=>'Sevillana','Seymour One'=>'Seymour One','Shadows Into Light'=>'Shadows Into Light','Shadows Into Light Two'=>'Shadows Into Light Two','Shanti'=>'Shanti','Share'=>'Share','Share Tech'=>'Share Tech','Share Tech Mono'=>'Share Tech Mono','Shojumaru'=>'Shojumaru','Short Stack'=>'Short Stack','Siemreap'=>'Siemreap','Sigmar One'=>'Sigmar One','Signika'=>'Signika','Signika Negative'=>'Signika Negative','Simonetta'=>'Simonetta','Sintony'=>'Sintony','Sirin Stencil'=>'Sirin Stencil','Six Caps'=>'Six Caps','Skranji'=>'Skranji','Slabo 13px'=>'Slabo 13px','Slabo 27px'=>'Slabo 27px','Slackey'=>'Slackey','Smokum'=>'Smokum','Smythe'=>'Smythe','Sniglet'=>'Sniglet','Snippet'=>'Snippet','Snowburst One'=>'Snowburst One','Sofadi One'=>'Sofadi One','Sofia'=>'Sofia','Sonsie One'=>'Sonsie One','Sorts Mill Goudy'=>'Sorts Mill Goudy','Source Code Pro'=>'Source Code Pro','Source Sans Pro'=>'Source Sans Pro','Source Serif Pro'=>'Source Serif Pro','Special Elite'=>'Special Elite','Spicy Rice'=>'Spicy Rice','Spinnaker'=>'Spinnaker','Spirax'=>'Spirax','Squada One'=>'Squada One','Sree Krushnadevaraya'=>'Sree Krushnadevaraya','Stalemate'=>'Stalemate','Stalinist One'=>'Stalinist One','Stardos Stencil'=>'Stardos Stencil','Stint Ultra Condensed'=>'Stint Ultra Condensed','Stint Ultra Expanded'=>'Stint Ultra Expanded','Stoke'=>'Stoke','Strait'=>'Strait','Sue Ellen Francisco'=>'Sue Ellen Francisco','Sunshiney'=>'Sunshiney','Supermercado One'=>'Supermercado One','Suranna'=>'Suranna','Suravaram'=>'Suravaram','Suwannaphum'=>'Suwannaphum','Swanky and Moo Moo'=>'Swanky and Moo Moo','Syncopate'=>'Syncopate','Tangerine'=>'Tangerine','Taprom'=>'Taprom','Tauri'=>'Tauri','Teko'=>'Teko','Telex'=>'Telex','Tenali Ramakrishna'=>'Tenali Ramakrishna','Tenor Sans'=>'Tenor Sans','Text Me One'=>'Text Me One','The Girl Next Door'=>'The Girl Next Door','Tienne'=>'Tienne','Timmana'=>'Timmana','Tinos'=>'Tinos','Titan One'=>'Titan One','Titillium Web'=>'Titillium Web','Trade Winds'=>'Trade Winds','Trocchi'=>'Trocchi','Trochut'=>'Trochut','Trykker'=>'Trykker','Tulpen One'=>'Tulpen One','Ubuntu'=>'Ubuntu','Ubuntu Condensed'=>'Ubuntu Condensed','Ubuntu Mono'=>'Ubuntu Mono','Ultra'=>'Ultra','Uncial Antiqua'=>'Uncial Antiqua','Underdog'=>'Underdog','Unica One'=>'Unica One','UnifrakturCook'=>'UnifrakturCook','UnifrakturMaguntia'=>'UnifrakturMaguntia','Unkempt'=>'Unkempt','Unlock'=>'Unlock','Unna'=>'Unna','Vampiro One'=>'Vampiro One','Varela'=>'Varela','Varela Round'=>'Varela Round','Vast Shadow'=>'Vast Shadow','Vesper Libre'=>'Vesper Libre','Vibur'=>'Vibur','Vidaloka'=>'Vidaloka','Viga'=>'Viga','Voces'=>'Voces','Volkhov'=>'Volkhov','Vollkorn'=>'Vollkorn','Voltaire'=>'Voltaire','VT323'=>'VT323','Waiting for the Sunrise'=>'Waiting for the Sunrise','Wallpoet'=>'Wallpoet','Walter Turncoat'=>'Walter Turncoat','Warnes'=>'Warnes','Wellfleet'=>'Wellfleet','Wendy One'=>'Wendy One','Wire One'=>'Wire One','Yanone Kaffeesatz'=>'Yanone Kaffeesatz','Yellowtail'=>'Yellowtail','Yeseva One'=>'Yeseva One','Yesteryear'=>'Yesteryear','Zeyada'=>'Zeyada');


	$wp_customize->add_section( 'apricot_general' , array(
		'title'      => __( 'Site Layout','apricot' ),
		'description'=> '',
		'priority'   => 10,
		) );
	$wp_customize->add_setting('apricot_header_logo', array(
		'sanitize_callback' => 'apricot_sanitize_logo'
		));
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'apricot_header_logo_1',
			array(
				'label'      => __( 'Header Logo Image','apricot' ),
				'section'    => 'apricot_general',
				'settings'   => 'apricot_header_logo',
				'priority'   => 9
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_favicon', array(
			'sanitize_callback' => 'apricot_sanitize_logo'
			));
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'upload_favicon',
			array(
				'label'      => __( 'Upload Favicon','apricot' ),
				'section'    => 'apricot_general',
				'settings'   => 'apricot_favicon',
				'priority'   => 10
				)
			)
		);

	$wp_customize->add_setting(
		'apricot_box_layout',
		array(
			'default'     => 'top',
			'sanitize_callback' => 'apricot_sanitize_string'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'home_layout_1',
			array(
				'label'          => __( 'Header Position','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_box_layout',
				'type'           => 'radio',
				'priority'   => 10,
				'choices'        => array(
					'top'   => 'Top',
					'left'  => 'Left'
					)
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_col_layout',
		array(
			'default'     => 'one',
			'sanitize_callback' => 'apricot_sanitize_string'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'home_layout_2',
			array(
				'label'          => __( 'Column Layout','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_col_layout',
				'type'           => 'radio',
				'priority'   => 10,
				'choices'        => array(
					'one'   => 'One',
					'two'  => 'Two'
					)
				)
			)
		);

	$wp_customize->add_setting(
		'apricot_sidebar_home',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_sidebar_home',
			array(
				'label'          => __( 'Show Sidebar on Home Page','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_sidebar_home',
				'type'           => 'checkbox',
				'priority'   => 10
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_sidebar_post',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_sidebar_post',
			array(
				'label'          => __( 'Show Sidebar on Posts','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_sidebar_post',
				'type'           => 'checkbox',
				'priority'   => 11
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_sidebar_page',
		array(
			'default'     => false,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_sidebar_page',
			array(
				'label'          => __( 'Show Sidebar on Pages','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_sidebar_page',
				'type'           => 'checkbox',
				'priority'   => 12
				)
			)
		);

	$wp_customize->add_setting(
		'apricot_sidebar_search',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_sidebar_search',
			array(
				'label'          => __( 'Show Sidebar on Search Page','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_sidebar_search',
				'type'           => 'checkbox',
				'priority'   => 13
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_sidebar_archive',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_sidebar_archive',
			array(
				'label'          => __( 'Show Sidebar on Archive Page','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_sidebar_archive',
				'type'           => 'checkbox',
				'priority'   => 14
				)
			)
		);

	$wp_customize->add_setting(
		'apricot_related_posts',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_related_posts',
			array(
				'label'          => __( 'Show Related Posts','apricot' ),
				'section'        => 'apricot_general',
				'settings'       => 'apricot_related_posts',
				'type'           => 'checkbox',
				'priority'   => 15
				)
			)
		);


	$wp_customize->add_section( 'apricot_theme' , array(
		'title'      => 'Theme Styling',
		'description'=> '',
		'priority'   => 12,
		) );
	$wp_customize->add_setting(
		'apricot_theme_color',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'apricot_theme_color_1',
			array(
				'label'      => __( 'Theme Color Scheme','apricot' ),
				'section'    => 'apricot_theme',
				'settings'   => 'apricot_theme_color',
				'priority'   => 10
				)
			)
		);

	$wp_customize->add_section( 'apricot_social' , array(
		'title'      => __( 'Social Links','apricot' ),
		'description'=> '',
		'priority'   => 15,
		) );
	$wp_customize->add_setting(
		'apricot_facebook',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_facebook',
			array(
				'label'          => __( 'Facebook Link','apricot' ),
				'section'        => 'apricot_social',
				'settings'       => 'apricot_facebook',
				'type'           => 'text',
				'priority'   => 10
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_twitter',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_twitter',
			array(
				'label'          => __( 'Twitter Link','apricot' ),
				'section'        => 'apricot_social',
				'settings'       => 'apricot_twitter',
				'type'           => 'text',
				'priority'   => 11
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_instagram',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_instagram',
			array(
				'label'          => __( 'Instagram Link','apricot' ),
				'section'        => 'apricot_social',
				'settings'       => 'apricot_instagram',
				'type'           => 'text',
				'priority'   => 11
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_pinterest',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_pinterest',
			array(
				'label'          => __( 'Pinterest Link','apricot' ),
				'section'        => 'apricot_social',
				'settings'       => 'apricot_pinterest',
				'type'           => 'text',
				'priority'   => 11
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_gplus',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_gplus',
			array(
				'label'          => __( 'Google Plus Link','apricot' ),
				'section'        => 'apricot_social',
				'settings'       => 'apricot_gplus',
				'type'           => 'text',
				'priority'   => 11
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_tumblr',
		array(
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_tumblr',
			array(
				'label'          => __( 'Tumblr Link','apricot' ),
				'section'        => 'apricot_social',
				'settings'       => 'apricot_tumblr',
				'type'           => 'text',
				'priority'   => 11
				)
			)
		);


	$wp_customize->add_section( 'apricot_other' , array(
		'title'      => __( 'Other Theme Options','apricot' ),
		'description'=> '',
		'priority'   => 16,
		) );
	$wp_customize->add_setting(
		'apricot_footer',
		array(
			'default'     => '',
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_footer',
			array(
				'label'          => __( 'Footer Text Top','apricot' ),
				'section'        => 'apricot_other',
				'settings'       => 'apricot_footer',
				'type'           => 'text',
				'priority'   => 11
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_footer2',
		array(
			'default'     => '',
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		); 
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_footer2',
			array(
				'label'          => __( 'Footer Text Bottom','apricot' ),
				'section'        => 'apricot_other',
				'settings'       => 'apricot_footer2',
				'type'           => 'text',
				'priority'   => 12
				)
			)
		);



	/* Fonts Section */
	$wp_customize->add_section( 'apricot_fonts' , array(
		'title'      => __( 'Google Fonts','apricot' ),
		'description'=> '',
		'priority'   => 17,
		) );
	$wp_customize->add_setting(
		'apricot_font_site_title',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_font_site_title',
			array(
				'label'          => __( 'Header Title','apricot' ),
				'section'        => 'apricot_fonts',
				'settings'       => 'apricot_font_site_title',
				'type'           => 'select',
				'priority'   => 1,
				'choices'        => $google_fonts
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_font_nav',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_font_nav',
			array(
				'label'          => __( 'Navigation Menu','apricot' ),
				'section'        => 'apricot_fonts',
				'settings'       => 'apricot_font_nav',
				'type'           => 'select',
				'priority'   => 2,
				'choices'        => $google_fonts
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_font_post_title',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_font_post_title',
			array(
				'label'          => __( 'Post Headings','apricot' ),
				'section'        => 'apricot_fonts',
				'settings'       => 'apricot_font_post_title',
				'type'           => 'select',
				'priority'   => 3,
				'choices'        => $google_fonts
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_font_widget_title',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_font_widget_title',
			array(
				'label'          => __( 'Widget Headings','apricot' ),
				'section'        => 'apricot_fonts',
				'settings'       => 'apricot_font_widget_title',
				'type'           => 'select',
				'priority'   => 4,
				'choices'        => $google_fonts
				)
			)
		);
	$wp_customize->add_setting(
		'apricot_font_general',
		array(
			'default'     => true,
			'sanitize_callback' => 'apricot_sanitize_basic'
			)
		);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'apricot_font_general',
			array(
				'label'          => __( 'General','apricot' ),
				'section'        => 'apricot_fonts',
				'settings'       => 'apricot_font_general',
				'type'           => 'select',
				'priority'   => 5,
				'choices'        => $google_fonts
				)
			)
		);

}
function apricot_sanitize_logo( $input ) {
	return esc_url_raw($input);
}
function apricot_sanitize_string( $input ) {
	return preg_replace("/[^A-Za-z ]/", '', $input);
}
function apricot_sanitize_basic( $input ) {
	return sanitize_text_field($input);
}


/* Site Author Widget */
class apricot_site_author extends WP_Widget {

	function apricot_site_author()
	{
		$widget_ops = array('classname' => 'apricot_site_author', 'description' => 'Author Profile (Apricot format)');
		$this->WP_Widget('apricot_site_author', 'Apricot Author Profile', $widget_ops);
	}

	public function widget( $args, $instance ) {

		$output = '';

		$image = ( ! empty( $instance['image'] ) ) ? $instance['image'] : '';
		$color = ( ! empty( $instance['color'] ) ) ? $instance['color'] : '';
		$user = ( ! empty( $instance['user'] ) ) ? $instance['user'] : '';

		$main_user = (array) get_userdata($user);

		$name = ( get_the_author_meta('display_name',$user)!=''  ) ? get_the_author_meta('display_name',$user) : '';
		$tag = ( get_the_author_meta('tag-line',$user)!=''  ) ? get_the_author_meta('tag-line',$user) : '';
		$bio = ( get_the_author_meta('description',$user)!=''  ) ? get_the_author_meta('description',$user) : '';

		$name = esc_attr($name);
		$color = esc_attr($color);
		$user = esc_attr($user);
		$bio = esc_attr($bio);

		$facebook = esc_attr(get_the_author_meta('facebook',$user));
		$twitter = esc_attr(get_the_author_meta('twitter',$user));
		$linkedin = esc_attr(get_the_author_meta('linkedin',$user));
		$instagram = esc_attr(get_the_author_meta('instagram',$user));
		$pinterest = esc_attr(get_the_author_meta('pinterest',$user));
		$gplus = esc_attr(get_the_author_meta('gplus',$user));
		$tumblr = esc_attr(get_the_author_meta('tumblr',$user));

		if ($args['id']=='sidebar-2')
		{
			$class = 'large-3 medium-6 small-12 column';
		}
		else
		{
			$class = '';
		}
		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;
		$author_link = count_user_posts($user)==0 ? 'javascript:return false();' : get_author_posts_url( $user );
		$author_link = esc_attr($author_link);
		$author_link = count_user_posts($user)==0 ? "<div class='site_author_name'>$name</div>" : "<a href='".$author_link."' class='site_author_name'>$name</a>";

		$output .= '<div data-equalizer-watch class="site_author widget card '.$class.' '.$args['widget_id'].'">';
		$output .= "<div class='site_author_image $color'>$author_link<div class='site_author_tag'>$tag</div><img alt='$name' src='$image'/></div>";
		$output .= "<div class='site_author_content'>";
		$output .= "<div class='site_author_bio'>$bio</div>";
		$output .= "<div class='social-links'>";
		$output .= $facebook!='' ? "<a target='_blank' href='".$facebook."'><i class='icon-facebook-squared'></i></a>" : "";
		$output .= $twitter!='' ? "<a target='_blank' href='".$twitter."'><i class='icon-twitter'></i></a>" : "";
		$output .= $linkedin!='' ? "<a target='_blank' href='".$linkedin."'><i class='icon-linkedin-squared'></i></a>" : "";
		$output .= $instagram!='' ? "<a target='_blank' href='".$instagram."'><i class='icon-instagramm'></i></a>" : "";
		$output .= $pinterest!='' ? "<a target='_blank' href='".$pinterest."'><i class='icon-pinterest-circled'></i></a>" : "";
		$output .= $gplus!='' ? "<a target='_blank' href='".$gplus."'><i class='icon-gplus'></i></a>" : "";
		$output .= $tumblr!='' ? "<a target='_blank' href='".$tumblr."'><i class='icon-tumblr'></i></a>" : "";
		$output .= "</div>";
		$output .= '</div></div>';

		echo $output;

	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['color'] = strip_tags($new_instance['color']);
		$instance['image'] = strip_tags($new_instance['image']);
		$instance['user'] = strip_tags($new_instance['user']);
		return $instance;
	}

	public function form( $instance ) {
		$color  = isset( $instance['color'] ) ? esc_attr( $instance['color'] ) : '';
		$image  = isset( $instance['image'] ) ? esc_attr( $instance['image'] ) : '';
		$user  = isset( $instance['user'] ) ? esc_attr( $instance['user'] ) : '';
		$colors = array('Light Red'=>'red','Aliceblue'=>'aliceblue', 'Lime'=>'lime','Beige'=>'beige',);
		$blogusers = get_users( 'orderby=display_name' );
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'color' ); ?>"><?php _e( 'Background Color:','apricot' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'color' ); ?>" id="<?php echo $this->get_field_id( 'color' ); ?>" class="widefat">
				<?php
				foreach ($colors as $key => $value) {
					if ($color==$value)
					{
						echo "<option selected value='$value'>$key</option>";
					}
					else
					{
						echo "<option value='$value'>$key</option>";
					}
				}
				?>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'user' ); ?>"><?php _e( 'User:','apricot' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'user' ); ?>" id="<?php echo $this->get_field_id( 'user' ); ?>" class="widefat">
				<?php
				foreach ( $blogusers as $users ) {
					if ($user==$users->ID)
					{
						echo '<option selected value="'.$users->ID.'">'.$users->display_name.'</option>';
					}
					else
					{
						echo '<option value="'.$users->ID.'">'.$users->display_name.'</option>';
					}
				}
				?>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'image' ); ?>"><?php _e( 'Display Image URL:','apricot' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'image' ); ?>" name="<?php echo $this->get_field_name( 'image' ); ?>" type="text" value="<?php echo $image; ?>" />
		</p>

		<?php
	}
}



/* Custom Comments Widget */
class apricot_recent_comments extends WP_Widget {

	function apricot_recent_comments()
	{
		$widget_ops = array('classname' => 'apricot_recent_comments', 'description' => 'Your site\'s most recent Comments. (Apricot format)');
		$this->WP_Widget('apricot_recent_comments', 'Apricot Recent Comments', $widget_ops);
	}

	public function recent_comments_style() {

		if ( ! current_theme_supports( 'widgets' ) // Temp hack #14876
			|| ! apply_filters( 'show_recent_comments_widget_style', true, $this->id_base ) )
		return;
	}

	public function flush_widget_cache() {
		wp_cache_delete('widget_recent_comments', 'widget');
	}

	public function widget( $args, $instance ) {
		global $comments, $comment;

		$cache = array();
		if ( ! $this->is_preview() ) {
			$cache = wp_cache_get('widget_recent_comments', 'widget');
		}
		if ( ! is_array( $cache ) ) {
			$cache = array();
		}

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		$output = '';

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Comments','apricot' );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;

		$comments = get_comments( apply_filters( 'widget_comments_args', array(
			'number'      => $number,
			'status'      => 'approve',
			'post_status' => 'publish'
			) ) );

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= $args['before_title'] . $title . $args['after_title'];
		}

		$output .= '<ul id="recentcomments" class="apricot_recent_comments">';
		if ( $comments ) {
			// Prime cache for associated posts. (Prime post term cache if we need it for permalinks.)
			$post_ids = array_unique( wp_list_pluck( $comments, 'comment_post_ID' ) );
			_prime_post_caches( $post_ids, strpos( get_option( 'permalink_structure' ), '%category%' ), false );

			foreach ( (array) $comments as $comment) {
				$output .= '<li class="recentcomments">'.get_avatar( $comment ).'<span>';
				/* translators: comments widget: 1: comment author, 2: post link */
				$output .= sprintf( _x( '%1$s on %2$s', 'widgets','apricot' ),
					'<span class="comment-author-link">' . get_comment_author_link() . '</span>',
					'<a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">' . get_the_title( $comment->comment_post_ID ) . '</a>'
					);
				$output .= '</span></li>';
			}
		}
		$output .= '</ul>';
		$output .= $args['after_widget'];

		echo $output;

		if ( ! $this->is_preview() ) {
			$cache[ $args['widget_id'] ] = $output;
			wp_cache_set( 'widget_recent_comments', $cache, 'widget' );
		}
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = absint( $new_instance['number'] );
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_recent_comments']) )
			delete_option('widget_recent_comments');

		return $instance;
	}

	public function form( $instance ) {
		$title  = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:','apricot' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of comments to show:','apricot' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" />
		</p>
		<?php
	}
}



/* Custom Recent Posts / Popular Posts Widget */
class apricot_recent_posts extends WP_Widget {

	function apricot_recent_posts()
	{
		$widget_ops = array('classname' => 'apricot_recent_posts', 'description' => 'Your site\'s most recent Posts. (Apricot format)');
		$this->WP_Widget('apricot_recent_posts', 'Apricot Recent Posts', $widget_ops);
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_recent_posts', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract($args);

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
		if ( ! $number )
			$number = 10;
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		$r = new WP_Query( apply_filters( 'widget_posts_args', array( 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
		if ($r->have_posts()) :
			?>
		<?php echo $before_widget; ?>
		<div class='widgettitle'><span class='active'><?php _e('Latest','apricot'); ?></span></div>
		<div class='apricot_recent_posts_cover'>
			<ul class='apricot_recent_posts_list recent active'>
				<?php while ( $r->have_posts() ) : $r->the_post(); ?>
					<?php
					$image = wp_get_attachment_image_src( get_post_thumbnail_id( ), 'thumbnail' );
					?>        
					<li>
						<a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>">
							<span class='img'><?php echo isset($image[0]) ? "<img alt='' src='$image[0]'/>":""; ?></span>
							<span class='text'>
								<span class="post-head"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></span>
								<span class="post-date"><?php echo get_the_date('M j, Y'); ?></span>
							</span>
						</a>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>
		<?php echo $after_widget; ?>
		<?php
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['sub_title'] = strip_tags($new_instance['sub_title']);
		$instance['number'] = (int) $new_instance['number'];
		$instance['show_date'] = (bool) $new_instance['show_date'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_recent_entries']) )
			delete_option('widget_recent_entries');

		return $instance;
	}

	function flush_widget_cache()
	{
		wp_cache_delete('widget_recent_posts', 'widget');
	}

	function form( $instance )
	{
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:','apricot' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3"/>
		</p>
		<?php
	}
}


function apricot_scripts_and_styles()
{

	global $theme_color, $sidebar_home, $sidebar_posts, $sidebar_archive, $box_layout, $theme_columns;
	$color = get_theme_mod('apricot_theme_color','#f08080');
	$color_dark = colourBrightness($color,1.1);
	$custom_css = "
	body
	{
		font-family: 'Source Sans Pro';
	}
	#top-nav li.current-menu-item > a,
	#top-nav li a:hover,
	.category-link,
	.more-link,
	#header h1,
	#header .small-logo,
	.backslash,
	.theme-color,
	.search-form-cover .icon-search,
	#mobile-menu,
	#header .search-form-cover.active > span:hover .icon-search,
	.comment-reply-link,
	.comment-reply-login,
	#header .social-links a,
	.apricot_recent_posts .widgettitle > span.active,
	.widgettitle,
	.pagination .nav-links span,
		#archive-head h2,
	.not-found h2,
	.icon-emo-unhappy,
	.single .author-right .entry-author,
	.comment-form > p label,
	.comment-form > p.form-submit input,
	.comment-form > p.form-submit button,
	.comment-edit-link,
	#reply-title small,
	#archive-head .author-right .entry-author,
	.textwidget a,
	ul.apricot_recent_comments li > span a,
	.email-sign,
	.comment-pagination span,
	.site_author_name,
	.page-links a
	{
		color: $color;
	}
	a:hover,
	.recentcomments a:hover,
	.search-form-cover > span:hover .icon-search,
		#header .social-links a:hover,
	.category-link a:hover,
	.relatedposts .relatedthumb a:hover h4,
	.comment-form > p.form-submit input:hover,
	.comment-form > p.form-submit button:hover,
	.textwidget a:hover,
	.page-links a:hover
	{
		color: $color_dark;
	}
		#sidebar1 .tagcloud > a,
		#archive-head .label-right,
	.apricot_form input[type='submit']
	{
		background-color: $color;
	}
		#sidebar1 .tagcloud > a:hover,
	.apricot_form input[type='submit']:hover
	{
		background-color: $color_dark;
	}

		#top-nav li .sub-menu
	{
		border-right-color: $color;
	}
		#sidebar1 .tagcloud > a:before,
	blockquote
	{
		border-left-color: $color;
	}
	.more-link,
	.header-layout-left #header .search-form-cover input,
		#header .search-form-cover form input,
	.widgettitle,
		#archive-head h2,
		#sidebar1 .tagcloud > a,
	.comment-form > p.form-submit input,
	.comment-form > p.form-submit button,
	.apricot_form input:focus,
	.apricot_form textarea:focus,
	body #top-nav li:hover .sub-menu,
	.widget_search .search-field
	{
		border-color: $color;
	}
	.more-link:hover,
	.comment-form > p.form-submit input:hover,
	.comment-form > p.form-submit button:hover
	{
		border-color: $color_dark;
	}";
	$fonts = array();

	if (get_theme_mod('apricot_font_site_title')!='')
	{
		$fonts[] = get_theme_mod('apricot_font_site_title');
		$custom_css.= "#header h1 { font-family: '".get_theme_mod('apricot_font_site_title')."', sans-serif; }";
	}
	if (get_theme_mod('apricot_font_nav')!='')
	{
		$fonts[] = get_theme_mod('apricot_font_nav');
		$custom_css.= "#top-nav li a { font-family: '".get_theme_mod('apricot_font_nav')."', sans-serif; }";
	}
	if (get_theme_mod('apricot_font_post_title')!='')
	{
		$fonts[] = get_theme_mod('apricot_font_post_title');
		$custom_css.= "#container .post-title { font-family: '".get_theme_mod('apricot_font_post_title')."', sans-serif; }";
	}
	if (get_theme_mod('apricot_font_widget_title')!='')
	{
		$fonts[] = get_theme_mod('apricot_font_widget_title');
		$custom_css.= "#container .widgettitle { font-family: '".get_theme_mod('apricot_font_widget_title')."', sans-serif; }";
	}
	if (get_theme_mod('apricot_font_general')!='')
	{
		$fonts[] = get_theme_mod('apricot_font_general');
		$custom_css.= "body { font-family: '".get_theme_mod('apricot_font_general')."', sans-serif; }";
	}	

	add_editor_style( get_stylesheet_uri() );

	/* Main CSS */
	wp_enqueue_style( 'apricot_style', get_stylesheet_directory_uri() . '/style.css', array(), '', 'all' );
	wp_add_inline_style( 'apricot_style', $custom_css );	

	/* Zurb Grid */
	wp_enqueue_style( 'apricot-grid', get_stylesheet_directory_uri() . '/assets/foundation.css', array(), '', 'all' );
	wp_enqueue_script( 'apricot-grid-js', get_stylesheet_directory_uri() . '/assets/foundation.min.js', array(), '', true );

	/* Fontello */
	wp_enqueue_style( 'apricot-fontello', get_stylesheet_directory_uri() . '/assets/fontello/css/apricot.css', array(), '', 'all' );

	/* Slider CSS */
	wp_enqueue_style( 'apricot-slick', get_stylesheet_directory_uri() . '/assets/slick.css', array(), '', 'all' );

	/* Fonts */
	wp_enqueue_style( 'source-sans-pro', '//fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,600,700' );

	/* Comments */
	wp_enqueue_script('comment-reply');

	/* Font Loader */
	wp_enqueue_script( 'apricot-webfont', get_stylesheet_directory_uri() . '/assets/webfont.js', array(), '', false );

	/* Theme Functions */
	wp_enqueue_script( 'apricot-script', get_stylesheet_directory_uri() . '/script.js', array('jquery'), '', true );
	wp_localize_script('apricot-script', 'apricot', array(
		'ajaxurl' => admin_url( 'admin-ajax.php' ),
		'fonts' => $fonts
		) );

	/* Slider JavaScript */
	wp_enqueue_script( 'apricot-slick', get_stylesheet_directory_uri() . '/assets/slick.min.js', array('jquery'), '', true );
}



/* Basic Stuff - Theme Functionality */
function apricot_theme_support() {

	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	//add_theme_support( 'custom-header' );
	//add_theme_support( 'custom-background' );
	add_theme_support( 'html5', array( 'post-thumbnails','comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
	set_post_thumbnail_size(125, 125, true);
	add_theme_support('automatic-feed-links');
	add_theme_support( 'post-formats',
		array(
			'gallery',        
			'image',          
			'video',          
			'quote',          
			'audio',          
			)
		);

	add_theme_support( 'menus' );
	register_nav_menus(
		array(
			'main-nav' => __( 'Primary Menu', 'apricot' )
			)
		);
}



/* Theme Palette Shades */
function colourBrightness($hex, $percent) {
	$hash = '';
	if (stristr($hex,'#')) {
		$hex = str_replace('#','',$hex);
		$hash = '#';
	}
	$rgb = array(hexdec(substr($hex,0,2)), hexdec(substr($hex,2,2)), hexdec(substr($hex,4,2)));
	for ($i=0; $i<3; $i++) {
		if ($percent > 0) {
			$rgb[$i] = round($rgb[$i] * $percent) + round(255 * (1-$percent));
		} else {
			$positivePercent = $percent - ($percent*2);
			$rgb[$i] = round($rgb[$i] * $positivePercent) + round(0 * (1-$positivePercent));
		}
		if ($rgb[$i] > 255) {
			$rgb[$i] = 255;
		}
	}
	$hex = '';
	for($i=0; $i < 3; $i++) {
		$hexDigit = dechex($rgb[$i]);
		if(strlen($hexDigit) == 1) {
			$hexDigit = "0" . $hexDigit;
		}
		$hex .= $hexDigit;
	}
	return $hash.$hex;
}
?>